@@ -46,6 +46,7 @@ SetValType {
     SET_VAL_STRING,  /**< string */
     SET_VAL_SETTING, /**< setting type */
     SET_VAL_ARRAY,   /**< array of values */
+    SET_VAL_NULL     /**< null item */
 } SetValType;
 /*----------------------------------------------------------------------------*/
 /**
@@ -124,13 +125,13 @@ Setting {
  */
 /*----------------------------------------------------------------------------*/
 static inline SetValType    setting_get_type (const Setting *st_setting) {
-    return st_setting->v_type;
+    return st_setting != NULL ? st_setting->v_type : SET_VAL_NULL;
 }
 static inline const char  * setting_get_name (const Setting *st_setting) {
-    return st_setting->s_name;
+    return st_setting != NULL ? st_setting->s_name : NULL;
 }
 static inline uint_fast32_t setting_get_hash (const Setting *st_setting) {
-    return st_setting->hash;
+    return st_setting != NULL ? st_setting->hash : 0;
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -150,7 +151,7 @@ static inline uint_fast32_t setting_get_hash (const Setting *st_setting) {
  */
 /*----------------------------------------------------------------------------*/
 static inline Setting * setting_get_parent (Setting *st_setting) {
-    return st_setting->parent;
+    return st_setting != NULL ? st_setting->parent : NULL;
 }
 
 Setting * setting_get_child  (Setting *st_setting);
@@ -172,10 +173,10 @@ Setting * setting_get_child  (Setting *st_setting);
  */
 /*----------------------------------------------------------------------------*/
 static inline Setting * setting_next (Setting *st_setting) {
-    return st_setting->next;
+    return st_setting != NULL ? st_setting->next : NULL;
 }
 static inline Setting * setting_prev (Setting *st_setting) {
-    return st_setting->prev;
+    return st_setting != NULL ? st_setting->prev : NULL;
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -320,15 +321,6 @@ Setting * setting_new_string  (const char *s_name,
                                const char *val)
           __attribute__ ((returns_nonnull));
 /*----------------------------------------------------------------------------*/
-/**
- * @brief  Duplicates a Setting
- *
- * @param[in]  st_src  Source Setting object
- * @return     New copy of Setting or null
- */
-Setting * setting_copy (const Setting *st_src)
-          __attribute__ ((returns_nonnull));
-/*----------------------------------------------------------------------------*/
 /**
  * @fn  Setting * setting_first (Setting *st_settings)
  *
@@ -395,18 +387,18 @@ size_t    settings_count         (const Setting *st_settings);
  * @brief  Remove Setting from list.
  *
  * @param[in] st_setting  Setting to remove
- * @return    none
+ * @return    Pointer to begining of list
  */
-void      setting_remove         (Setting *st_setting);
+Setting * setting_remove         (Setting *st_setting);
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Replace Setting st_old in list with st_new.
  *
  * @param[in,out] st_old  Old Setting item to be replaced
  * @param[in,out] st_new  New Setting item to replace old one
- * @return        none
+ * @return        Pointer to first element in Setting list
  */
-void      setting_replace        (Setting       *st_old,
+Setting * setting_replace        (Setting       *st_old,
                                   Setting       *st_new);
 /*----------------------------------------------------------------------------*/
 /**
@@ -416,14 +408,14 @@ void      setting_replace        (Setting       *st_old,
  * name of st_setting Setting. After finding such setting it will be replaced
  * with st_seting. If i_multi is set to 0, fuction stops after first replace,
  * if i_multi is set to 1, funciton replaces all found settings. Function
- * returns number of replaces performed.
+ * returns beginning of Setting list.
  *
  * @param[in,out] st_list     List of Setting items
  * @param[in,out] st_setting  Destination Setting
  * @param[in]     i_multi     Multiple replaces value
- * @return        Number of replaces performed.
+ * @return        Beginning of Setting list
  */
-int       settings_find_replace  (Setting       *st_list,
+Setting * settings_find_replace  (Setting       *st_list,
                                   Setting       *st_setting,
                                   const int      i_multi);
 /*----------------------------------------------------------------------------*/
@@ -476,20 +468,20 @@ int       settings_find_replace  (Setting       *st_list,
  * @return     none
  */
 /*----------------------------------------------------------------------------*/
-void setting_add_child          (Setting *st_parent,
-                                 Setting *st_child);
+void      setting_add_child          (Setting *st_parent,
+                                      Setting *st_child);
 
-void settings_prepend           (Setting *st_list,
-                                 Setting *st_setting);
+Setting * settings_prepend           (Setting *st_list,
+                                      Setting *st_setting);
 
-void settings_append            (Setting *st_list,
-                                 Setting *st_setting);
+Setting * settings_append            (Setting *st_list,
+                                      Setting *st_setting);
 
-void settings_append_or_ignore  (Setting *st_list,
-                                 Setting *st_setting);
+void      settings_append_or_ignore  (Setting *st_list,
+                                      Setting *st_setting);
 
-void settings_append_or_replace (Setting *st_list,
-                                 Setting *st_setting);
+Setting * settings_append_or_replace (Setting *st_list,
+                                      Setting *st_setting);
 /*----------------------------------------------------------------------------*/
 /**
  * @fn  Setting * setting_get_top_level (Setting *st_setting)
