@@ -96,8 +96,7 @@ ImageInfo * treemodel_get_data           (GtkTreeModel   *gtm_model,
 
 GSList    * treeview_get_data            (GtkWidget      *gw_tview);
 
-void        treeview_get_setting_data    (GtkWidget      *gw_tview,
-                                          Setting        *st_wallpapers);
+Setting *   treeview_get_setting_data    (GtkWidget      *gw_tview);
 /*----------------------------------------------------------------------------*/
 /**
  * @fn  void treeview_remove_duplicates (GtkWidget *gw_tview)
@@ -153,10 +152,9 @@ void treeview_find_select_item  (GtkWidget  *gw_tview,
 /**
  * @brief  Create treeview for image list.
  *
- * @param[out]  gw_tview  Pointer to Treeview to set
- * @return      none
+ * @return Result TreeView
  */
-void create_tview (GtkWidget **gw_tview);
+GtkWidget * create_tview (void);
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Get one file path from wallpaper list.
