@@ -19,9 +19,9 @@
  *
  * Automatic wallpaper changer
  *
- * @date November 8, 2020
+ * @date November 13, 2020
  *
- * @version 1.6.11
+ * @version 1.6.12
  *
  * @author Michal Babik <michal.babik@pm.me>
  */
@@ -243,12 +243,11 @@ static void        event_stop_daemon_pressed    (DialogData        *dd_data);
 static gboolean    daemon_monitor              (gpointer data);
 /*----------------------------------------------------------------------------*/
 /**
- * @fn static void create_title_widget (GtkWidget **gw_widget)
+ * @fn static GtkWidget * create_title_widget (void)
  *
  * @brief  Create top window title text.
  *
- * @param[out] gw_widget  Widget to write data
- * @return     none
+ * @return     Result widget
  *
  * @fn  static GtkWidget * create_image_button (const char   *s_label,
  *                                              const char   *s_hint,
@@ -260,22 +259,19 @@ static gboolean    daemon_monitor              (gpointer data);
  * @param[in] i_but    Icon number
  * @return    Button
  *
- * @fn  static void create_buttons_widget (GtkWidget **gw_widget,
- *                                         DialogData *dd_data)
+ * @fn  static GtkWidget * create_buttons_widget (DialogData *dd_data)
+ *
  * @brief  Create side buttons widget.
  *
- * @param[out]    gw_widget  Pointer to widget where to set buttons
  * @param[in,out] dd_data    DialogData object with widgets and settings info
- * @return        none
+ * @return        Result widget
  *
- * @fn  static void create_settings_widget (GtkWidget **gw_widget,
- *                                          DialogData *dd_data)
+ * @fn  static GtkWidget * create_settings_widget (DialogData *dd_data)
  *
  * @brief  Creates widget with settings for wallpaper changing.
  *
- * @param[out]    gw_widget  Pointer to destination widget
  * @param[in,out] dd_data    DialogData object with settings and widget data
- * @return        none
+ * @return        Settings widget
  *
  * @fn  static GtkWidget * create_daemon_widget (DialogData *dd_data)
  *
@@ -285,17 +281,15 @@ static gboolean    daemon_monitor              (gpointer data);
  * @return        none
  */
 /*----------------------------------------------------------------------------*/
-static void        create_title_widget         (GtkWidget        **gw_widget);
+static GtkWidget * create_title_widget         (void);
 
 static GtkWidget * create_image_button         (const char        *s_label,
                                                 const char        *s_hint,
                                                 const IconImg      i_but);
 
-static void        create_buttons_widget       (GtkWidget        **gw_widget,
-                                                DialogData        *dd_data);
+static GtkWidget * create_buttons_widget       (DialogData        *dd_data);
 
-static void        create_settings_widget      (GtkWidget        **gw_widget,
-                                                DialogData        *dd_data);
+static GtkWidget * create_settings_widget      (DialogData        *dd_data);
 
 static GtkWidget * create_daemon_widget        (DialogData        *dd_data);
 /*----------------------------------------------------------------------------*/
@@ -321,37 +315,26 @@ static void        activate                    (GtkApplication    *app,
 static char *
 cfgfile_check_create_dirs (void)
 {
-    char *s_dir = NULL;
+    char *s_ret = NULL;
     int   i_err = ERR_OK;
+    int   i     = 0;
+    char *s_dirs[3];
 
-    s_dir = cfgfile_get_query_path ();
-    i_err = dir_create_with_subdirs (s_dir);
-    if (i_err != ERR_OK) {
-        str_append (&s_dir, "\n");
-        str_append (&s_dir, err_get_message (i_err));
-        return s_dir;
+    s_dirs[0] = cfgfile_get_query_path ();
+    s_dirs[1] = cfgfile_get_app_thumbnails_path ();
+    s_dirs[2] = cfgfile_get_app_wallpapers_path ();
+
+    for (i = 0; i < 3; ++i) {
+        if ((i_err = dir_create_with_subdirs (s_dirs[i])) != ERR_OK) {
+            s_ret = str_comb (s_dirs[i], "\n");
+            str_append (&s_ret, err_get_message (i_err));
+            break;
+        }
     }
-    free (s_dir);
-
-    s_dir = cfgfile_get_app_thumbnails_path ();
-    i_err = dir_create_with_subdirs (s_dir);
-    if (i_err != ERR_OK) {
-        str_append (&s_dir, "\n");
-        str_append (&s_dir, err_get_message (i_err));
-        return s_dir;
+    for (i = 0; i < 3; ++i) {
+        free (s_dirs[i]);
     }
-    free (s_dir);
-
-    s_dir = cfgfile_get_app_wallpapers_path ();
-    i_err = dir_create_with_subdirs (s_dir);
-    if (i_err != ERR_OK) {
-        str_append (&s_dir, "\n");
-        str_append (&s_dir, err_get_message (i_err));
-        return s_dir;
-    }
-    free (s_dir);
-
-    return NULL;
+    return s_ret;
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -405,47 +388,43 @@ set_wallpaper_ch_interval (const DialogData *dd_data,
 static Setting *
 widgets_get_settings (const DialogData *dd_data)
 {
-    Setting    *st_settings;   /* setting list to return */
-    Setting    *st_sett;       /* setting to add */
-    const char *s_val  = NULL; /* Value for a string setting */
-    int64_t     i_val  = 0;    /* Value for an integer setting */
-
-    st_settings = setting_new_setting ("Settings");
+    Setting    *st_setts = NULL; /* Setting item to return */
+    const char *s_val    = NULL; /* Value for a string setting */
+    int64_t     i_val    = 0;    /* Value for an integer setting */
 
     /* Get wallpaper list from treeview and add to settlist */
-    st_sett = setting_new_array (get_setting_name (SETT_WALL_ARRAY));
-    treeview_get_setting_data (dd_data->gw_view, st_sett);
-    setting_add_child (st_settings, st_sett);
+    st_setts = setting_new_array (get_setting_name (SETT_WALL_ARRAY));
+    setting_add_child (st_setts, treeview_get_setting_data (dd_data->gw_view));
 
     /* Get random wallpaper setting */
     i_val = (int64_t) gtk_toggle_button_get_active (
                 GTK_TOGGLE_BUTTON (dd_data->gw_random));
-    setting_add_child (st_settings,
+    settings_append (st_setts,
             setting_new_int (get_setting_name (SETT_RANDOM_OPT), i_val));
 
     /* Get last used wallpaper on start setting */
     i_val = (int64_t) gtk_toggle_button_get_active (
                 GTK_TOGGLE_BUTTON (dd_data->gw_lastused));
-    setting_add_child (st_settings,
+    settings_append (st_setts,
             setting_new_int (get_setting_name (SETT_LAST_USED_OPT), i_val));
 
     /* Get time align setting */
     i_val = (int64_t) gtk_toggle_button_get_active (
                 GTK_TOGGLE_BUTTON (dd_data->gw_timealign));
-    setting_add_child (st_settings,
+    settings_append (st_setts,
             setting_new_int (get_setting_name (SETT_TIME_ALIGN_OPT), i_val));
 
     /* Get wallpaper change interval setting */
     i_val = (int64_t) get_wallpaper_ch_interval (dd_data);
-    setting_add_child (st_settings,
+    settings_append (st_setts,
             setting_new_int (get_setting_name (SETT_INTERVAL_VAL), i_val));
 
     /* Get wallpaper set command */
     s_val = gtk_entry_get_text (GTK_ENTRY (dd_data->gw_command));
-    setting_add_child (st_settings,
+    settings_append (st_setts,
             setting_new_string (get_setting_name (SETT_BG_CMD), s_val));
 
-    return st_settings;
+    return st_setts;
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -453,7 +432,7 @@ widgets_get_settings (const DialogData *dd_data)
  */
 static void
 widgets_set_settings (const DialogData *dd_data,
-                      Setting          *st_settings,
+                      Setting          *st_setts,
                       Setting          *st_wmlist,
                       int              *i_err)
 {
@@ -467,7 +446,7 @@ widgets_set_settings (const DialogData *dd_data,
 
     /* Check window managers and set wallpaper set command */
     s_cmd = wms_get_wallpaper_command (dd_data->s_cfg_file,
-                                       st_settings,
+                                       st_setts,
                                        st_wmlist,
                                        i_err);
     if (*i_err != ERR_OK) {
@@ -478,44 +457,41 @@ widgets_set_settings (const DialogData *dd_data,
     free (s_cmd);
 
     /* Set last used wallpaper on start setting */
-    st_item = settings_find (st_settings,
-                             get_setting_name (SETT_LAST_USED_OPT));
+    st_item = settings_find (st_setts, get_setting_name (SETT_LAST_USED_OPT));
     if (st_item != NULL) {
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dd_data->gw_lastused),
                                       (gboolean) setting_get_int (st_item));
     }
     /* Set minutes/hours of wallpaper change interval */
-    st_item = settings_find (st_settings, get_setting_name (SETT_INTERVAL_VAL));
+    st_item = settings_find (st_setts, get_setting_name (SETT_INTERVAL_VAL));
     if (st_item != NULL) {
         set_wallpaper_ch_interval (dd_data,
                                    (uint32_t) setting_get_int (st_item));
     }
     /* Set wallpaper random choose setting */
-    st_item = settings_find (st_settings, get_setting_name (SETT_RANDOM_OPT));
+    st_item = settings_find (st_setts, get_setting_name (SETT_RANDOM_OPT));
     if (st_item != NULL) {
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dd_data->gw_random),
                                       (gboolean) setting_get_int (st_item));
     }
     /* Set time align setting */
-    st_item = settings_find (st_settings,
-                             get_setting_name (SETT_TIME_ALIGN_OPT));
+    st_item = settings_find (st_setts, get_setting_name (SETT_TIME_ALIGN_OPT));
     if (st_item != NULL) {
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dd_data->gw_timealign),
                                       (gboolean) setting_get_int (st_item));
     }
     /* Get wallpaper list and add to treeview */
-    st_item = settings_find (st_settings,
-                             get_setting_name (SETT_WALL_ARRAY));
+    st_item = settings_find (st_setts, get_setting_name (SETT_WALL_ARRAY));
     if (st_item != NULL) {
         treeview_add_items_setting (dd_data->gw_view,
                                     setting_get_child (st_item));
     }
     /* Set window dimensions */
-    st_item = settings_find (st_settings, get_setting_name (SETT_WIN_WIDTH));
+    st_item = settings_find (st_setts, get_setting_name (SETT_WIN_WIDTH));
     if (st_item != NULL) {
         i_w = (int) setting_get_int (st_item);
     }
-    st_item = settings_find (st_settings, get_setting_name (SETT_WIN_HEIGHT));
+    st_item = settings_find (st_setts, get_setting_name (SETT_WIN_HEIGHT));
     if (st_item != NULL) {
         i_h = (int) setting_get_int (st_item);
     }
@@ -523,8 +499,7 @@ widgets_set_settings (const DialogData *dd_data,
 
     /* Check if there is last used wallpaper info, if it is select it on
      * list and make a preview image */
-    st_item = settings_find (st_settings,
-                             get_setting_name (SETT_LAST_USED_STR));
+    st_item = settings_find (st_setts, get_setting_name (SETT_LAST_USED_STR));
     if (st_item != NULL)
         s_lastused = setting_get_string (st_item);
 
@@ -560,11 +535,8 @@ event_add_img_pressed (const DialogData *dd_data)
     GSList *gsl_files = NULL; /* List with files from dialog */
 
     /* Run image select dialog and get selected files */
-    gsl_files = add_images_dialog (dd_data->gw_window);
-
-    /* Add items to TreeView */
-    if (gsl_files != NULL) {
-
+    if ((gsl_files = add_images_dialog (dd_data->gw_window)) != NULL) {
+        /* Add items to TreeView */
         treeview_add_items_gslist (dd_data->gw_view, gsl_files);
         g_slist_free_full (gsl_files, g_free);
     }
@@ -580,13 +552,9 @@ event_add_img_dir_pressed (const DialogData *dd_data)
     GList *gl_files = NULL;  /* Images in directory */
 
     /* Run directory select dialog and get selected directory name */
-    s_folder = add_images_folder_dialog (dd_data->gw_window);
-
-    if (s_folder != NULL) {
+    if ((s_folder = add_images_folder_dialog (dd_data->gw_window)) != NULL) {
         /* Scan directory for files and append them to file list */
-        gl_files = get_dir_content_filter_images (s_folder);
-
-        if (gl_files != NULL) {
+        if ((gl_files = get_dir_content_filter_images (s_folder)) != NULL) {
             /* Add items to TreeView */
             treeview_add_items_glist (dd_data->gw_view, gl_files);
             g_list_free_full (gl_files, g_free);
@@ -638,7 +606,7 @@ event_set_wallpaper_pressed (const DialogData *dd_data)
         ii_info = treemodel_get_data (gtm_model, gti_iter);
         s_cmd   = gtk_entry_get_text (GTK_ENTRY (dd_data->gw_command));
         i_err   = wallpaper_dialog_set (s_cmd,
-                                        imageinfo_get_full_name (ii_info),
+                                        imageinfo_get_file_path (ii_info),
                                         dialogdata_get_cfg_file (dd_data));
         if (i_err != ERR_OK) {
             message_dialog_error (dd_data->gw_window, err_get_message (i_err));
@@ -659,7 +627,7 @@ event_save_settings_pressed (const DialogData *dd_data)
 
     st_settings = widgets_get_settings (dd_data);
     i_err = setts_check_update_file (dialogdata_get_cfg_file (dd_data),
-                                     setting_get_child (st_settings));
+                                     st_settings);
     settings_free_all (st_settings);
 
     if (i_err != ERR_OK) {
@@ -686,7 +654,7 @@ event_img_list_activated (GtkTreeView       *tree_view,
 
         ii_info = treemodel_get_data (gtm_model, gti_iter);
 
-        preview_from_file (gw_img_prev, imageinfo_get_full_name (ii_info));
+        preview_from_file (gw_img_prev, imageinfo_get_file_path (ii_info));
         imageinfo_free (ii_info);
     }
 }
@@ -821,7 +789,7 @@ event_on_delete (GtkWidget        *window,
     st_settings = widgets_get_settings (dd_data);
 
     s_buff  = setts_check_update (dialogdata_get_cfg_file (dd_data),
-                                  setting_get_child (st_settings),
+                                  st_settings,
                                   &i_err);
     settings_free_all (st_settings);
 
@@ -911,24 +879,26 @@ daemon_monitor (gpointer data)
 /**
  * @brief  Create top window title text.
  */
-static void
-create_title_widget (GtkWidget **gw_widget)
+static GtkWidget *
+create_title_widget (void)
 {
+    GtkWidget  *gw_widget; /* Widget to return */
     const char *s_str    = APP_NAME " - Program settings";
     const char *s_format = "<span size=\"20000\" weight=\"bold\" "
                            "foreground=\"#0099e6\" style=\"italic\">%s</span>";
     char       *s_markup = NULL;
     GtkWidget  *gw_label = gtk_label_new (NULL);
 
-    *gw_widget = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 4);
+    gw_widget = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 4);
 
     s_markup = g_markup_printf_escaped (s_format, s_str);
     gtk_label_set_markup (GTK_LABEL (gw_label), s_markup);
     g_free (s_markup);
 
-    gtk_box_pack_start (GTK_BOX (*gw_widget),
+    gtk_box_pack_start (GTK_BOX (gw_widget),
                         gw_label,
                         FALSE, FALSE, 24);
+    return gw_widget;
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -962,16 +932,16 @@ create_image_button (const char   *s_label,
 /**
  * @brief  Create side buttons widget.
  */
-static void
-create_buttons_widget (GtkWidget  **gw_widget,
-                       DialogData  *dd_data)
+static GtkWidget *
+create_buttons_widget (DialogData  *dd_data)
 {
+    GtkWidget *gw_widget;
     GtkWidget *gw_button;
 
-    *gw_widget = gtk_box_new (GTK_ORIENTATION_VERTICAL, 4);
+    gw_widget = gtk_box_new (GTK_ORIENTATION_VERTICAL, 4);
 
     gw_button = create_image_button (NULL, "Add images", W_ICON_ADD);
-    gtk_box_pack_start (GTK_BOX (*gw_widget),
+    gtk_box_pack_start (GTK_BOX (gw_widget),
                         gw_button,
                         FALSE, FALSE, 4);
     g_signal_connect_swapped (gw_button,
@@ -984,7 +954,7 @@ create_buttons_widget (GtkWidget  **gw_widget,
                               "clicked",
                               G_CALLBACK (event_add_img_dir_pressed),
                               dd_data);
-    gtk_box_pack_start (GTK_BOX (*gw_widget),
+    gtk_box_pack_start (GTK_BOX (gw_widget),
                         gw_button,
                         FALSE, FALSE, 4);
     gw_button = create_image_button (NULL, "Add wallpapers from web",
@@ -993,12 +963,12 @@ create_buttons_widget (GtkWidget  **gw_widget,
                               "clicked",
                               G_CALLBACK (event_add_img_web_pressed),
                               dd_data);
-    gtk_box_pack_start (GTK_BOX (*gw_widget),
+    gtk_box_pack_start (GTK_BOX (gw_widget),
                         gw_button,
                         FALSE, FALSE, 4);
     gw_button = create_image_button (NULL, "Remove selected images",
                                      W_ICON_REMOVE);
-    gtk_box_pack_start (GTK_BOX (*gw_widget),
+    gtk_box_pack_start (GTK_BOX (gw_widget),
                         gw_button,
                         FALSE, FALSE, 4);
     g_signal_connect_swapped (gw_button,
@@ -1006,7 +976,7 @@ create_buttons_widget (GtkWidget  **gw_widget,
                               G_CALLBACK (treeview_remove_selected),
                               dd_data->gw_view);
     gw_button = create_image_button (NULL, "Move up", W_ICON_UP);
-    gtk_box_pack_start (GTK_BOX (*gw_widget),
+    gtk_box_pack_start (GTK_BOX (gw_widget),
                         gw_button,
                         FALSE, FALSE, 4);
     g_signal_connect_swapped (gw_button,
@@ -1014,7 +984,7 @@ create_buttons_widget (GtkWidget  **gw_widget,
                               G_CALLBACK (treeview_move_up),
                               dd_data->gw_view);
     gw_button = create_image_button (NULL, "Move down", W_ICON_DOWN);
-    gtk_box_pack_start (GTK_BOX (*gw_widget),
+    gtk_box_pack_start (GTK_BOX (gw_widget),
                         gw_button,
                         FALSE, FALSE, 4);
     g_signal_connect_swapped (gw_button,
@@ -1022,7 +992,7 @@ create_buttons_widget (GtkWidget  **gw_widget,
                               G_CALLBACK (treeview_move_down),
                               dd_data->gw_view);
     gw_button = create_image_button (NULL, "Remove duplicates", W_ICON_DUPL);
-    gtk_box_pack_start (GTK_BOX (*gw_widget),
+    gtk_box_pack_start (GTK_BOX (gw_widget),
                         gw_button,
                         FALSE, FALSE, 4);
     g_signal_connect_swapped (gw_button,
@@ -1030,7 +1000,7 @@ create_buttons_widget (GtkWidget  **gw_widget,
                               G_CALLBACK (treeview_remove_duplicates),
                               dd_data->gw_view);
     gw_button = create_image_button (NULL, "Set wallpaper", W_ICON_SCREEN);
-    gtk_box_pack_start (GTK_BOX (*gw_widget),
+    gtk_box_pack_start (GTK_BOX (gw_widget),
                         gw_button,
                         FALSE, FALSE, 4);
     g_signal_connect_swapped (gw_button,
@@ -1038,7 +1008,7 @@ create_buttons_widget (GtkWidget  **gw_widget,
                               G_CALLBACK (event_set_wallpaper_pressed),
                               dd_data);
     gw_button = create_image_button (NULL, "Save settings", W_ICON_FLOPPY);
-    gtk_box_pack_start (GTK_BOX (*gw_widget),
+    gtk_box_pack_start (GTK_BOX (gw_widget),
                         gw_button,
                         FALSE, FALSE, 4);
     g_signal_connect_swapped (gw_button,
@@ -1046,7 +1016,7 @@ create_buttons_widget (GtkWidget  **gw_widget,
                               G_CALLBACK (event_save_settings_pressed),
                               dd_data);
     gw_button = create_image_button (NULL, "Other settings", W_ICON_SETTING);
-    gtk_box_pack_start (GTK_BOX (*gw_widget),
+    gtk_box_pack_start (GTK_BOX (gw_widget),
                         gw_button,
                         FALSE, FALSE, 4);
     g_signal_connect_swapped (gw_button,
@@ -1054,7 +1024,7 @@ create_buttons_widget (GtkWidget  **gw_widget,
                               G_CALLBACK (event_other_settings_pressed),
                               dd_data);
     gw_button = create_image_button (NULL, "About Wall Changer", W_ICON_INFO);
-    gtk_box_pack_start (GTK_BOX (*gw_widget),
+    gtk_box_pack_start (GTK_BOX (gw_widget),
                         gw_button,
                         FALSE, FALSE, 4);
     g_signal_connect_swapped (gw_button,
@@ -1067,18 +1037,19 @@ create_buttons_widget (GtkWidget  **gw_widget,
                               "clicked",
                               G_CALLBACK (gtk_window_close),
                               dd_data->gw_window);
-    gtk_box_pack_start (GTK_BOX (*gw_widget),
+    gtk_box_pack_start (GTK_BOX (gw_widget),
                         gw_button,
                         FALSE, FALSE, 4);
+    return gw_widget;
 }
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Creates widget with settings for wallpaper changing.
  */
-static void
-create_settings_widget (GtkWidget **gw_widget,
-                        DialogData *dd_data)
+static GtkWidget *
+create_settings_widget (DialogData *dd_data)
 {
+    GtkWidget     *gw_widget;            /* Widget to return */
     GtkWidget     *gw_random_button;     /* Random image GtkCheckButton */
     GtkWidget     *gw_button_selectlast; /* Set last used GtkCheckButton */
     GtkWidget     *gw_align_button;      /* Time align GtkCheckButton */
@@ -1113,7 +1084,7 @@ create_settings_widget (GtkWidget **gw_widget,
     /* Time align button */
     gw_align_button = gtk_check_button_new ();
     gtk_widget_set_tooltip_markup (gw_align_button, 
-        "This option enables time aligning, when <b>enabled</b> wallpaper"
+        "This option enables time align, when <b>enabled</b> wallpaper"
         " change intervals will be set for changes to appear on full hour."
         "\ne.g. interval is set to 20 minutes, daemon starts at"
         " 10:15, first interval will be changed to 5 minutes so changes"
@@ -1125,7 +1096,6 @@ create_settings_widget (GtkWidget **gw_widget,
     gw_command_label = gtk_label_new ("Background set command : ");
     gtk_label_set_xalign (GTK_LABEL (gw_command_label), 0);
     gw_command_entry = gtk_entry_new ();
-    //gtk_entry_set_width_chars (GTK_ENTRY (gw_command_entry), 70);
 
     gtk_widget_set_tooltip_markup (gw_command_entry,
         "This command will be executed to set background image\n"
@@ -1185,51 +1155,52 @@ create_settings_widget (GtkWidget **gw_widget,
     dd_data->gw_inter_combo = gw_time_combo;
 
     /* Container for settings widgets */
-    *gw_widget = gtk_grid_new ();
-    gtk_grid_set_column_spacing (GTK_GRID (*gw_widget), 8);
-    gtk_grid_set_row_spacing (GTK_GRID (*gw_widget), 8);
-    gtk_grid_set_row_homogeneous (GTK_GRID (*gw_widget), TRUE);
+    gw_widget = gtk_grid_new ();
+    gtk_grid_set_column_spacing (GTK_GRID (gw_widget), 8);
+    gtk_grid_set_row_spacing (GTK_GRID (gw_widget), 8);
+    gtk_grid_set_row_homogeneous (GTK_GRID (gw_widget), TRUE);
 
     /* Packing time interval widgets */
-    gtk_grid_attach (GTK_GRID (*gw_widget),
+    gtk_grid_attach (GTK_GRID (gw_widget),
                      gw_interval_label, 0, 0, 1, 1);
-    gtk_grid_attach_next_to (GTK_GRID (*gw_widget),
+    gtk_grid_attach_next_to (GTK_GRID (gw_widget),
                              gw_spinbutton, gw_interval_label,
                              GTK_POS_RIGHT, 1, 1);
-    gtk_grid_attach_next_to (GTK_GRID (*gw_widget),
+    gtk_grid_attach_next_to (GTK_GRID (gw_widget),
                              gw_time_combo, gw_spinbutton,
                              GTK_POS_RIGHT, 1, 1);
-    gtk_grid_attach_next_to (GTK_GRID (*gw_widget),
+    gtk_grid_attach_next_to (GTK_GRID (gw_widget),
                              gw_align_button, gw_time_combo,
                              GTK_POS_RIGHT, 1, 1);
 
     /* Packing background set command */
-    gtk_grid_attach_next_to (GTK_GRID (*gw_widget),
+    gtk_grid_attach_next_to (GTK_GRID (gw_widget),
                              gw_command_label, gw_interval_label,
                              GTK_POS_BOTTOM, 1, 1);
-    gtk_grid_attach_next_to (GTK_GRID (*gw_widget),
+    gtk_grid_attach_next_to (GTK_GRID (gw_widget),
                              gw_command_entry, gw_command_label,
                              GTK_POS_RIGHT, 2, 1);
-    gtk_grid_attach_next_to (GTK_GRID (*gw_widget),
+    gtk_grid_attach_next_to (GTK_GRID (gw_widget),
                              gw_command_button, gw_command_entry,
                              GTK_POS_RIGHT, 1, 1);
 
     /* Separator for checkbuttons */
-    gtk_grid_attach (GTK_GRID (*gw_widget),
+    gtk_grid_attach (GTK_GRID (gw_widget),
                      gtk_separator_new (GTK_ORIENTATION_VERTICAL),
                      4, 0, 1, 3);
 
     /* Packing button for random change */
-    gtk_grid_attach (GTK_GRID (*gw_widget),
+    gtk_grid_attach (GTK_GRID (gw_widget),
                      gw_random_button, 5, 0, 1, 1);
-    gtk_grid_attach_next_to (GTK_GRID (*gw_widget),
+    gtk_grid_attach_next_to (GTK_GRID (gw_widget),
                              gw_button_selectlast, gw_random_button,
                              GTK_POS_BOTTOM, 1, 1);
 
     /* Packing autostart widget */
-    gtk_grid_attach_next_to (GTK_GRID (*gw_widget),
+    gtk_grid_attach_next_to (GTK_GRID (gw_widget),
                              gw_autostart_button, gw_button_selectlast,
                              GTK_POS_BOTTOM, 1, 1);
+    return gw_widget;
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -1276,6 +1247,7 @@ create_daemon_widget (DialogData *dd_data)
     gtk_grid_attach (GTK_GRID (gw_widget), gw_button, 1, 2, 1, 1);
 
     gtk_widget_set_halign (gw_widget, GTK_ALIGN_CENTER);
+
     return gw_widget;
 }
 /*----------------------------------------------------------------------------*/
@@ -1313,8 +1285,7 @@ activate (GtkApplication *app,
 
     /* Main window */
     gw_window = gtk_application_window_new (app);
-    gtk_window_set_title (GTK_WINDOW (gw_window),
-                          APP_NAME " v" APP_VER);
+    gtk_window_set_title (GTK_WINDOW (gw_window), APP_NAME " v" APP_VER);
     g_signal_connect (gw_window, "delete-event",
                       G_CALLBACK (event_on_delete), dd_data);
     dd_data->gw_window = GTK_WINDOW (gw_window);
@@ -1332,24 +1303,21 @@ activate (GtkApplication *app,
         g_object_unref (gd_pix);
     }
     /* Treeview for background file list */
-    create_tview (&gw_tview);
+    gw_tview = create_tview ();
     dd_data->gw_view = gw_tview;
     g_signal_connect (gw_tview, "row-activated",
                       G_CALLBACK (event_img_list_activated), gw_img_prev);
     g_signal_connect (G_OBJECT (gw_tview), "key-press-event",
                       G_CALLBACK (event_treeview_key_press), dd_data);
 
-    create_title_widget (&gw_title_widget);
-
-    create_buttons_widget (&gw_buttons_widget, dd_data);
+    gw_title_widget    = create_title_widget ();
+    gw_buttons_widget  = create_buttons_widget (dd_data);
+    gw_settings_widget = create_settings_widget (dd_data);
+    gw_statusbar       = gtk_statusbar_new ();
+    dd_data->gw_statusbar = gw_statusbar;
 
     preview_from_file (gw_img_prev, NULL);
 
-    create_settings_widget (&gw_settings_widget, dd_data);
-
-    gw_statusbar = gtk_statusbar_new ();
-    dd_data->gw_statusbar = gw_statusbar;
-
     /* Scrolled window for TreeView */
     gw_scroll = gtk_scrolled_window_new (NULL, NULL);
     gtk_container_add (GTK_CONTAINER (gw_scroll), gw_tview);
@@ -1424,10 +1392,7 @@ activate (GtkApplication *app,
     }
     setts_check_defaults (st_settings);
 
-    widgets_set_settings (dd_data,
-                          setting_get_child (st_settings),
-                          setting_get_child (st_wm),
-                          &i_err);
+    widgets_set_settings (dd_data, st_settings, st_wm, &i_err);
 
     settings_free_all (st_wm);
     settings_free_all (st_settings);
