@@ -40,6 +40,9 @@
 #include "webwidget_c.h"
 #include "webabyss.h"
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Enum with available search options.
+ */
 enum e_options {
     GW_WIDTH,    /**< Spinbutton with width */
     GW_HEIGHT,   /**< Spinbutton with height */
@@ -262,10 +265,6 @@ wallpaperabyss_search (WebWidget         *ww_widget,
     if (str_is_empty_msg (fs_data->s_str1, "Wallpaper Abyss API key is not set"))
         return;
 
-    /* Check if there is a cached info about this search query */
-    if (check_for_cached_query (ww_widget, ww_name (WEB_WIDGET_WALLABYSS)))
-        return;
-
     s_query = str_replace_in (ww_widget->s_query, " ", "+");
 
     ud_data = urldata_search_wallabyss (s_query,
@@ -284,7 +283,6 @@ wallpaperabyss_search (WebWidget         *ww_widget,
         gtk_list_store_clear (GTK_LIST_STORE (gtk_icon_view_get_model (
                     GTK_ICON_VIEW (ww_widget->gw_img_view))));
 
-        printf ("res : %s\n", ud_data->buffer);
         wallpaperabyss_json_to_webwidget (ud_data->buffer, ww_widget, cq_query);
         cq_query->i_found_cnt = ww_widget->i_found_cnt;
 
@@ -422,8 +420,10 @@ get_search_opts (GtkWidget **gw_array)
              GTK_SPIN_BUTTON (gw_array[GW_HEIGHT]));
 
     if (i_valw > 0 && i_valh > 0) {
-        st_sett = setting_new_int (s_opts[GW_WIDTH], i_valw);
-        settings_append (st_sett, setting_new_int (s_opts[GW_HEIGHT], i_valh));
+        st_sett = settings_append (st_sett,
+                setting_new_int (s_opts[GW_WIDTH], i_valw));
+        st_sett = settings_append (st_sett,
+                setting_new_int (s_opts[GW_HEIGHT], i_valh));
     }
     return st_sett;
 }
@@ -492,7 +492,7 @@ wallpaperabyss_search_opts_dialog (WebWidget *ww_widget)
     gtk_box_pack_start (GTK_BOX (gw_content_box), gw_hbox, FALSE, FALSE, 4);
 
     st_settings = setts_read (ww_widget->s_cfg_file, &i_err);
-    set_search_opts (gw_array, setting_get_child (st_settings));
+    set_search_opts (gw_array, st_settings);
     settings_free_all (st_settings);
 
     gtk_widget_show_all (gw_content_box);
