@@ -299,9 +299,6 @@ pexels_search (WebWidget         *ww_widget,
 
     if (str_is_empty_msg (fs_data->s_str1, "Pexels API key is not set"))
         return;
-    /* Check if there is a cached info about this search query */
-    if (check_for_cached_query (ww_widget, ww_name (WEB_WIDGET_PEXELS)))
-        return;
 
     s_query = str_replace_in (ww_widget->s_query, " ", "+");
 
@@ -491,7 +488,7 @@ pexels_search_opts_dialog (WebWidget *ww_widget)
     gtk_box_pack_start (GTK_BOX (gw_content_box), gw_hbox, FALSE, FALSE, 4);
 
     st_settings = setts_read (ww_widget->s_cfg_file, &i_err);
-    set_search_opts (gw_per_page, setting_get_child (st_settings));
+    set_search_opts (gw_per_page, st_settings);
     settings_free_all (st_settings);
 
     gtk_widget_show_all (gw_content_box);
