@@ -290,10 +290,6 @@ wallhaven_search (WebWidget         *ww_widget,
     if (str_is_empty_msg (fs_data->s_str1, "Wallhaven API key is not set"))
         return;
 
-    /* Check if there is a cached info about this search query */
-    if (check_for_cached_query (ww_widget, ww_name (WEB_WIDGET_WALLHAVEN)))
-        return;
-
     s_query = str_replace_in (ww_widget->s_query, " ", "+");
 
     ud_data = urldata_search_wallhaven (s_query,
@@ -507,16 +503,18 @@ get_search_opts (GtkWidget **gw_array)
     char       *s_val2  = NULL;
     const char *s_cval  = NULL;
     gboolean    b_val   = FALSE;
+    int         i       = 0;
 
     /* Getting sorting info */
     s_val = gtk_combo_box_text_get_active_text (
             GTK_COMBO_BOX_TEXT (gw_array[GW_SORTING]));
-    st_sett = setting_new_string (s_opts[GW_SORTING], s_val);
+    st_sett = settings_append (st_sett,
+            setting_new_string (s_opts[GW_SORTING], s_val));
     /* If toplist is set */
     if (strcmp (s_val, s_sort[5]) == 0) {
         s_val2 = gtk_combo_box_text_get_active_text (
                  GTK_COMBO_BOX_TEXT (gw_array[GW_TOPRANGE]));
-        settings_append (st_sett,
+        st_sett = settings_append (st_sett,
                          setting_new_string (s_opts[GW_TOPRANGE], s_val2));
         free (s_val2);
     }
@@ -526,7 +524,7 @@ get_search_opts (GtkWidget **gw_array)
     s_val = gtk_combo_box_text_get_active_text (
             GTK_COMBO_BOX_TEXT (gw_array[GW_ORDER]));
     if (strcmp (s_val, s_order[0]) != 0) {
-        settings_append (st_sett,
+        st_sett = settings_append (st_sett,
                          setting_new_string (s_opts[GW_ORDER], s_val));
     }
     free (s_val);
@@ -534,38 +532,40 @@ get_search_opts (GtkWidget **gw_array)
     /* Getting at least value */
     s_cval = gtk_entry_get_text (GTK_ENTRY (gw_array[GW_ATLEAST]));
     if (s_cval[0] != '\0') {
-        settings_append (st_sett,
+        st_sett = settings_append (st_sett,
                          setting_new_string (s_opts[GW_ATLEAST], s_cval));
     }
     /* Getting resolutions */
     s_cval = gtk_entry_get_text (GTK_ENTRY (gw_array[GW_RESOLUTIONS]));
     if (s_cval[0] != '\0') {
-        settings_append (st_sett,
+        st_sett = settings_append (st_sett,
                          setting_new_string (s_opts[GW_RESOLUTIONS], s_cval));
     }
     /* Getting ratios */
     s_cval = gtk_entry_get_text (GTK_ENTRY (gw_array[GW_RATIOS]));
     if (s_cval[0] != '\0') {
-        settings_append (st_sett,
+        st_sett = settings_append (st_sett,
                          setting_new_string (s_opts[GW_RATIOS], s_cval));
     }
     /* Getting category value */
     s_val = strdup ("");
-    for (int i = GW_CATEG1; i <= GW_CATEG3; ++i) {
+    for (i = GW_CATEG1; i <= GW_CATEG3; ++i) {
         b_val = gtk_check_menu_item_get_active (
                 GTK_CHECK_MENU_ITEM (gw_array[i]));
         str_append (&s_val, b_val ? "1" : "0");
     }
-    settings_append (st_sett, setting_new_string (s_opts[GW_CATEG1], s_val));
+    st_sett = settings_append (st_sett,
+            setting_new_string (s_opts[GW_CATEG1], s_val));
     free (s_val);
     /* Getting purity value */
     s_val = strdup ("");
-    for (int i = GW_PURITY1; i <= GW_PURITY3; ++i) {
+    for (i = GW_PURITY1; i <= GW_PURITY3; ++i) {
         b_val = gtk_check_menu_item_get_active (
                 GTK_CHECK_MENU_ITEM (gw_array[i]));
         str_append (&s_val, b_val ? "1" : "0");
     }
-    settings_append (st_sett, setting_new_string (s_opts[GW_PURITY1], s_val));
+    st_sett = settings_append (st_sett,
+            setting_new_string (s_opts[GW_PURITY1], s_val));
     free (s_val);
 
     return st_sett;
@@ -766,7 +766,7 @@ wallhaven_search_opts_dialog (WebWidget *ww_widget)
     gtk_box_pack_start (GTK_BOX (gw_content_box), gw_hbox, FALSE, FALSE, 4);
 
     st_settings = setts_read (ww_widget->s_cfg_file, &i_err);
-    set_search_opts (gw_array, setting_get_child (st_settings));
+    set_search_opts (gw_array, st_settings);
     settings_free_all (st_settings);
 
     gtk_widget_show_all (gw_content_box);
