@@ -29,6 +29,7 @@
 #include "errs.h"
 #include "chquery.h"
 #include "strfun.h"
+#include "setts.h"
 #include "webwidget_c.h"
 /*----------------------------------------------------------------------------*/
 /**
@@ -81,6 +82,132 @@ ww_opts (const int i_site)
     return NULL;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get webwidget logo image id based on webwidget if.
+ */
+int
+ww_logo_id (const int i_site)
+{
+    switch (i_site) {
+        case WEB_WIDGET_PEXELS:
+            return W_LOGO_PEXELS;
+        case WEB_WIDGET_PIXBAY:
+            return W_LOGO_PIXBAY;
+        case WEB_WIDGET_WALLHAVEN:
+            return W_LOGO_WALLHAVEN;
+        case WEB_WIDGET_WALLABYSS:
+            return W_LOGO_WALLABYSS;
+#ifdef HAVE_FLICKCURL
+        case WEB_WIDGET_FLICKR:
+            return W_LOGO_FLICKR;
+#endif
+        default:
+            break;
+    }
+    return -1;
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get settings API names.
+ *
+ * @param[in] i_site  Site id
+ * @return    FourStrings item with API names
+ */
+static FourStrings *
+ww_get_api_key_names (const int i_site)
+{
+    FourStrings *fs_data = NULL;
+
+    fs_data = fourstrings_new (FS_VAL_EMPTY);
+
+    switch (i_site) {
+        case WEB_WIDGET_PEXELS:
+            str_append (&fs_data->s_str1, "Pexels api");
+            break;
+        case WEB_WIDGET_PIXBAY:
+            str_append (&fs_data->s_str1, "Pixbay api");
+            break;
+        case WEB_WIDGET_WALLHAVEN:
+            str_append (&fs_data->s_str1, "Wallhaven api");
+            break;
+        case WEB_WIDGET_WALLABYSS:
+            str_append (&fs_data->s_str1, "Wallpaper Abyss api");
+            break;
+#ifdef HAVE_FLICKCURL
+        case WEB_WIDGET_FLICKR:
+            str_append (&fs_data->s_str1, "Flickr client key");
+            str_append (&fs_data->s_str2, "Flickr client secret");
+            str_append (&fs_data->s_str3, "Flickr access token");
+            str_append (&fs_data->s_str4, "Flickr access token secret");
+            break;
+#endif
+        default:
+            break;
+    }
+    return fs_data;
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get API key data of given service from settings.
+ */
+FourStrings *
+ww_get_api_key_data (Setting  *st_settings,
+                     const int i_site)
+{
+    FourStrings *fs_key_names = NULL;  /* API key names in settings */
+    FourStrings *fs_data      = NULL;  /* Data to rerutn */
+    Setting     *st_sett      = NULL;  /* For individual setting */
+    const char  *s_api        = NULL;  /* For API key */
+
+    fs_key_names = ww_get_api_key_names (i_site);
+    fs_data      = fourstrings_new (FS_VAL_EMPTY);
+
+    for (int i = 0; i < 4; ++i) {
+        if (*fs_key_names->s_str[i][0] != '\0') {
+            st_sett = settings_find (st_settings, *fs_key_names->s_str[i]);
+            s_api   = st_sett == NULL ? "" : setting_get_string (st_sett);
+            str_append (fs_data->s_str[i], s_api);
+        }
+    }
+    fourstrings_free (fs_key_names);
+
+    return fs_data;
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Update API key data in settings.
+ */
+int
+ww_update_api_key_data (const char  *s_cfg_file,
+                        FourStrings *fs_key_data,
+                        const int    i_site)
+{
+    Setting     *st_setts;
+    FourStrings *fs_key_names;
+    int          i_res = ERR_OK;
+
+    fs_key_names = ww_get_api_key_names (i_site);
+
+    st_setts = setting_new_string (fs_key_names->s_str1, fs_key_data->s_str1);
+
+#ifdef HAVE_FLICKCURL
+    if (i_site == WEB_WIDGET_FLICKR) {
+        st_setts = settings_append (st_setts,
+            setting_new_string (fs_key_names->s_str2, fs_key_data->s_str2));
+        st_setts = settings_append (st_setts,
+            setting_new_string (fs_key_names->s_str3, fs_key_data->s_str3));
+        st_setts = settings_append (st_setts,
+            setting_new_string (fs_key_names->s_str4, fs_key_data->s_str4));
+    }
+#endif
+    i_res = setts_check_update_file (s_cfg_file, st_setts);
+    settings_free_all (st_setts);
+
+    fourstrings_free (fs_key_names);
+
+    return i_res;
+}
+/*----------------------------------------------------------------------------*/
 /**
  * @brief  Check if string s_txt is null or empty and show message s_msg
  *         if it is.
@@ -175,6 +302,15 @@ combo_get_active_str (GtkWidget *gw_combo,
     return s_ret;
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Check if given wallpaper is already in wallpaper dir and mark gp_pbuf
+ *         with check mark if it is.
+ *
+ * @param[in]  s_wallp_dir  Wallpaper directory
+ * @param[in]  s_file_name  Wallpaper file to check
+ * @param[out] gp_pbuf      Thumbnail pixbuf
+ * @retutn     none
+ */
 static void
 wallpaper_check_mark (const char *s_wallp_dir,
                       const char *s_file_name,
